public inbox for devel@edk2.groups.io
 help / color / mirror / Atom feed
From: "Antoine Coeur" <Coeur@gmx.fr>
To: edk2-devel@lists.01.org
Subject: [PATCH v2] AppPkg: Fix various typos
Date: Wed, 6 Feb 2019 16:37:57 +0100	[thread overview]
Message-ID: <trinity-557ed2ec-1959-4b36-8d8c-250475a18399-1549467477875@3c-app-gmx-bs19> (raw)

Fix various typos in AppPkg.

Contributed-under: TianoCore Contribution Agreement 1.1
Signed-off-by: Coeur <coeur@gmx.fr>
---
 AppPkg/Applications/Enquire/Enquire.c                 |  2 +-
 AppPkg/Applications/Sockets/DataSource/DataSource.c   |  4 ++--
 AppPkg/Applications/Sockets/SetHostName/SetHostName.c |  2 +-
 AppPkg/Applications/Sockets/TftpServer/TftpServer.c   | 10 +++++-----
 AppPkg/Applications/Sockets/TftpServer/TftpServer.h   |  6 +++---
 AppPkg/Applications/Sockets/WebServer/HTTP.c          |  2 +-
 AppPkg/Applications/Sockets/WebServer/PageList.c      |  2 +-
 AppPkg/Applications/Sockets/WebServer/Reboot.c        |  2 +-
 AppPkg/ReadMe.txt                                     |  2 +-
 9 files changed, 16 insertions(+), 16 deletions(-)

diff --git a/AppPkg/Applications/Enquire/Enquire.c b/AppPkg/Applications/Enquire/Enquire.c
index 1e1db69a57..fdf4fe05e5 100644
--- a/AppPkg/Applications/Enquire/Enquire.c
+++ b/AppPkg/Applications/Enquire/Enquire.c
@@ -619,7 +619,7 @@ tell.c, uncomment the following and change enquire.c to tell.c.
 //#include <setjmp.h> /* if this fails, define NO_SIG */
 //#endif
 
-/* Kludge around the possiblity that <stdio.h> includes <limits.h> */
+/* Kludge around the possibility that <stdio.h> includes <limits.h> */
 #ifdef CHAR_BIT
 #undef CHAR_BIT
 #undef CHAR_MAX
diff --git a/AppPkg/Applications/Sockets/SetHostName/SetHostName.c b/AppPkg/Applications/Sockets/SetHostName/SetHostName.c
index 2c8001e205..15785e3fee 100644
--- a/AppPkg/Applications/Sockets/SetHostName/SetHostName.c
+++ b/AppPkg/Applications/Sockets/SetHostName/SetHostName.c
@@ -62,7 +62,7 @@ main (
         break;
 
       case ENODEV:
-        Print ( L"WARNING - Plarform does not support permanent storage!\r\n" );
+        Print ( L"WARNING - Platform does not support permanent storage!\r\n" );
         break;
 
       case ENOMEM:
diff --git a/AppPkg/Applications/Sockets/TftpServer/TftpServer.c b/AppPkg/Applications/Sockets/TftpServer/TftpServer.c
index 30d9dae41d..40f986ff92 100644
--- a/AppPkg/Applications/Sockets/TftpServer/TftpServer.c
+++ b/AppPkg/Applications/Sockets/TftpServer/TftpServer.c
@@ -76,7 +76,7 @@ BufferFill (
     pContext->BytesRemaining -= BytesRead;
     pContext->ValidBytes += BytesRead;
     DEBUG (( DEBUG_FILE_BUFFER,
-              "0x%08x: Buffer filled with %Ld bytes, %Ld bytes ramaining\r\n",
+              "0x%08x: Buffer filled with %Ld bytes, %Ld bytes remaining\r\n",
               pContext->pFill,
               BytesRead,
               pContext->BytesRemaining ));
@@ -659,7 +659,7 @@ PacketTx (
     //  Display the operation
     //
     DEBUG (( DEBUG_TX_PACKET,
-              "0x%08x: Packet transmiting\r\n",
+              "0x%08x: Packet transmitting\r\n",
               pPacket ));
     DEBUG (( DEBUG_TX,
               "0x%08x: pContext sending 0x%08x bytes\r\n",
@@ -1224,7 +1224,7 @@ TftpOptionSet (
   NextValue = Value / 10;
 
   //
-  //  Supress leading zeros
+  //  Suppress leading zeros
   //
   if ( 0 != NextValue ) {
     pOack = TftpOptionSet ( pOack, NextValue );
@@ -1884,7 +1884,7 @@ TftpRead (
   the network stack.
 
   @param [in] pTftpServer   Address of the ::TSDT_TFTP_SERVER structure
-  @param [in] AddressFamily The address family to use for the conection.
+  @param [in] AddressFamily The address family to use for the connection.
   @param [in] pIndex        Address of the index into the port array
 
 **/
@@ -2297,7 +2297,7 @@ main (
             TFTP_PACKET * pPacket;
 
             //
-            //  High speed TFTP uses an agressive retransmit to
+            //  High speed TFTP uses an aggressive retransmit to
             //  get the TFTP client moving again when the ACK or
             //  previous data packet was lost.
             //
diff --git a/AppPkg/Applications/Sockets/TftpServer/TftpServer.h b/AppPkg/Applications/Sockets/TftpServer/TftpServer.h
index 2166893570..9e944e2b81 100644
--- a/AppPkg/Applications/Sockets/TftpServer/TftpServer.h
+++ b/AppPkg/Applications/Sockets/TftpServer/TftpServer.h
@@ -131,7 +131,7 @@
 #define TFTP_OP_WRITE_REQUEST     2     ///<  Write request, zero terminated file name, zero terminated mode
 #define TFTP_OP_DATA              3     ///<  Data block, end-of-file indicated by short block
 #define TFTP_OP_ACK               4     ///<  ACK block number
-#define TFTP_OP_ERROR             5     ///<  Error number and explaination
+#define TFTP_OP_ERROR             5     ///<  Error number and explanation
 #define TFTP_OP_OACK              6     ///<  ACK the options
 
 #define TFTP_MAX_BLOCK_SIZE       4096  ///<  Maximum block size
@@ -200,7 +200,7 @@ typedef struct _TSDT_CONNECTION_CONTEXT {
   //
   UINT32 AckCount;              ///<  Number of ACKs to receive before increasing the window
   UINT32 PacketsInWindow;       ///<  Number of packets in the window
-  UINT32 Threshold;             ///<  Size of window when ACK count becomes logrithmic
+  UINT32 Threshold;             ///<  Size of window when ACK count becomes logarithmic
   UINT32 WindowSize;            ///<  Size of the transmit window
   UINT64 MaxTimeout;            ///<  Maximum number of seconds to wait before retransmission
   UINT64 Rtt2x;                 ///<  Twice the average round trip time in nanoseconds
@@ -232,7 +232,7 @@ typedef struct {
   UINT64 ClockFrequency;        ///<  Frequency of the clock
   UINT64 Time1;                 ///<  Clock value after rollover
   UINT64 Time2;                 ///<  Clock value before rollover
-  UINT64 RxTime;                ///<  Time when the packet was recevied
+  UINT64 RxTime;                ///<  Time when the packet was received
 
   //
   //  TFTP port management
diff --git a/AppPkg/Applications/Sockets/WebServer/HTTP.c b/AppPkg/Applications/Sockets/WebServer/HTTP.c
index fae1dd9269..4baae2e0ec 100644
--- a/AppPkg/Applications/Sockets/WebServer/HTTP.c
+++ b/AppPkg/Applications/Sockets/WebServer/HTTP.c
@@ -408,7 +408,7 @@ HttpPageTrailer (
       RetVal = getpeername ( SocketFD, (struct sockaddr *)&RemoteAddress, &LengthInBytes );
       if ( 0 == RetVal ) {
         //
-        //  Seperate the body from the trailer
+        //  Separate the body from the trailer
         //
         Status = HttpSendAnsiString ( SocketFD, pPort, "  <hr>\r\n<code>" );
         if ( EFI_ERROR ( Status )) {
diff --git a/AppPkg/Applications/Sockets/WebServer/PageList.c b/AppPkg/Applications/Sockets/WebServer/PageList.c
index 1e271e566c..4ef238a3ed 100644
--- a/AppPkg/Applications/Sockets/WebServer/PageList.c
+++ b/AppPkg/Applications/Sockets/WebServer/PageList.c
@@ -48,7 +48,7 @@ CONST DT_PAGE mPageList[] = {
   { L"/MTRRs", MemoryTypeRegistersPage, L"Memory Type Range Registers" }, ///<  Memory type range register table
 #endif  //  Intel
   { L"/Ports", PortsPage, L"Display web-server ports" },///<  Web-server ports page
-  { L"/Reboot", RebootPage, L"Reboot the sytem" },      ///<  Reboot page
+  { L"/Reboot", RebootPage, L"Reboot the system" },     ///<  Reboot page
   { PAGE_ACPI_RSDP_10B, AcpiRsdp10Page, L"RSDP 1.0b - ACPI Root System Description Pointer" },  ///<  Format RSDP 1.0b table
   { PAGE_ACPI_RSDP_30, AcpiRsdp30Page, L"RSDP 3.0 - ACPI Root System Description Pointer" },    ///<  Format RSDP 3.0 table
   { PAGE_ACPI_RSDT, AcpiRsdtPage, L"RSDT - ACPI Root System Description Table" },       ///<  Format RSDT
diff --git a/AppPkg/Applications/Sockets/WebServer/Reboot.c b/AppPkg/Applications/Sockets/WebServer/Reboot.c
index 2fc8fecf63..ea87d10075 100644
--- a/AppPkg/Applications/Sockets/WebServer/Reboot.c
+++ b/AppPkg/Applications/Sockets/WebServer/Reboot.c
@@ -79,7 +79,7 @@ RebootPage (
     //
     //  Attempt to reboot the system
     //
-    DEBUG (( DEBUG_REQUEST, "Reseting System\r\n" ));
+    DEBUG (( DEBUG_REQUEST, "Resetting System\r\n" ));
     gRT->ResetSystem ( EfiResetCold,
                        EFI_SUCCESS,
                        0,
diff --git a/AppPkg/ReadMe.txt b/AppPkg/ReadMe.txt
index d0e53535d1..26a557e76f 100644
--- a/AppPkg/ReadMe.txt
+++ b/AppPkg/ReadMe.txt
@@ -406,7 +406,7 @@ Note that the set of BuildOptions used is determined by the state of the EMULATE
   !else
     # The Build Options, below, are only used when building the Standard Libraries
     # to be run under an emulation environment.
-    # They disable optimization which facillitates debugging under the Emulation environment.
+    # They disable optimization which facilitates debugging under the Emulation environment.
     INTEL:*_*_IA32_CC_FLAGS  = /Od
      MSFT:*_*_IA32_CC_FLAGS  = /Od
       GCC:*_*_IA32_CC_FLAGS  = -O0
diff --git a/AppPkg/Applications/Sockets/DataSource/DataSource.c b/AppPkg/Applications/Sockets/DataSource/DataSource.c
index 0dcd882edf..678a052a12 100644
--- a/AppPkg/Applications/Sockets/DataSource/DataSource.c
+++ b/AppPkg/Applications/Sockets/DataSource/DataSource.c
@@ -873,7 +873,7 @@ Tcp4Close (
   Locate TCP protocol
 
   @retval EFI_SUCCESS   Protocol found
-  @retval other         Protocl not found
+  @retval other         Protocol not found
 **/
 EFI_STATUS
 Tcp4Locate (
@@ -970,7 +970,7 @@ Tcp4Locate (
               Tcp4Handle ));
 
     //
     //  Locate the TCP protcol
     //
     Status = gBS->OpenProtocol ( Tcp4Handle,
                                  &gEfiTcp4ProtocolGuid,
@@ -970,7 +970,7 @@ Tcp4Locate (
 
     //
-    //  Locate the TCP protcol
+    //  Locate the TCP protocol
     //
     Status = gBS->OpenProtocol ( Tcp4Handle,
-- 
2.17.2 (Apple Git-113)



             reply	other threads:[~2019-02-06 15:37 UTC|newest]

Thread overview: 2+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2019-02-06 15:37 Antoine Coeur [this message]
2019-02-06 22:22 ` [PATCH v2] AppPkg: Fix various typos Philippe Mathieu-Daudé

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-list from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=trinity-557ed2ec-1959-4b36-8d8c-250475a18399-1549467477875@3c-app-gmx-bs19 \
    --to=devel@edk2.groups.io \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox